@@ -1,4 +1,4 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python2.5
 import sys, tempfile, os, shutil, StringIO
 import unittest
 import logging
@@ -11,8 +11,8 @@ warnings.filterwarnings("ignore", category = DeprecationWarning)
 os.environ['HOME'] = '/home/idontexist'
 
 sys.path.insert(0, '..')
-from zeroinstall.injector import trust, autopolicy, namespaces, qdom
-from zeroinstall.injector import model, iface_cache, cli, download, writer, distro
+from zeroinstall.injector import namespaces, qdom
+from zeroinstall.injector import iface_cache, download, distro
 from zeroinstall.zerostore import Store; Store._add_with_helper = lambda *unused: False
 from zeroinstall import support
 from zeroinstall.support import basedir
