@@ -1,6 +1,6 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python2.5
 from basetest import BaseTest
-import sys, tempfile, os, shutil, imp
+import sys, tempfile, os
 from StringIO import StringIO
 import unittest
 import logging
@@ -8,7 +8,7 @@ import logging
 foo_iface_uri = 'http://foo'
 
 sys.path.insert(0, '..')
-from zeroinstall.injector import trust, autopolicy, namespaces, model, iface_cache, cli
+from zeroinstall.injector import autopolicy, model, cli
 from zeroinstall.zerostore import Store; Store._add_with_helper = lambda *unused: False
 from zeroinstall.support import basedir
 
@@ -18,16 +18,7 @@ class SilenceLogger(logging.Filter):
 silenceLogger = SilenceLogger()
 
 class TestLaunch(BaseTest):
-	def cache_iface(self, name, data):
-		cached_ifaces = basedir.save_cache_path('0install.net',
-							'interfaces')
-
-		f = file(os.path.join(cached_ifaces, model.escape(name)), 'w')
-		f.write(data)
-		f.close()
-
 	def run_0launch(self, args):
-		sys.argv = ['0launch'] + args
 		old_stdout = sys.stdout
 		old_stderr = sys.stderr
 		try:
@@ -35,7 +26,7 @@ class TestLaunch(BaseTest):
 			sys.stderr = StringIO()
 			ex = None
 			try:
-				imp.load_source('launch', '../0launch')
+				cli.main(args)
 				print "Finished"
 			except NameError:
 				raise
@@ -100,18 +91,18 @@ class TestLaunch(BaseTest):
 		assert err
 	
 	def testOK(self):
-		out, err = self.run_0launch(['--dry-run', 'http://foo'])
-		self.assertEquals("Would download 'http://foo'\nFinished\n", out)
+		out, err = self.run_0launch(['--dry-run', 'http://foo/d'])
+		self.assertEquals("Would download 'http://foo/d'\nFinished\n", out)
 		self.assertEquals("", err)
 	
 	def testOffline(self):
-		out, err = self.run_0launch(['--offline', 'http://foo'])
-		self.assertEquals("Can't find all required implementations:\n- <Interface http://foo> -> None\n", err)
+		out, err = self.run_0launch(['--offline', 'http://foo/d'])
+		self.assertEquals("Can't find all required implementations:\n- <Interface http://foo/d> -> None\n", err)
 		self.assertEquals("", out)
 
 	def testDisplay(self):
 		os.environ['DISPLAY'] = ':foo'
-		out, err = self.run_0launch(['--dry-run', 'http://foo'])
+		out, err = self.run_0launch(['--dry-run', 'http://foo/d'])
 		# Uses local copy of GUI
 		assert out.startswith("Would execute: ")
 		assert 'basetest.py' in out
@@ -124,7 +115,7 @@ class TestLaunch(BaseTest):
 
 	def testRefreshDisplay(self):
 		os.environ['DISPLAY'] = ':foo'
-		out, err = self.run_0launch(['--dry-run', '--refresh', 'http://foo'])
+		out, err = self.run_0launch(['--dry-run', '--refresh', 'http://foo/d'])
 		assert out.startswith("Would execute: ")
 		assert 'basetest.py' in out
 		self.assertEquals("", err)
@@ -169,7 +160,7 @@ class TestLaunch(BaseTest):
 		log.removeFilter(silenceLogger)
 		log.setLevel(logging.WARN)
 	
-	def testHelp(self):
+	def testHelp2(self):
 		out, err = self.run_0launch(['--help'])
 		self.assertEquals("", err)
 		assert 'options:' in out.lower()
