@@ -1,6 +1,6 @@
-#!/usr/bin/env python2.4
+#!/usr/bin/env python2.5
 from basetest import BaseTest
-import sys, tempfile, os, shutil
+import sys
 import unittest
 
 thomas_fingerprint = "92429807C9853C0744A68B9AAE07828059A53CC1"
@@ -8,7 +8,6 @@ thomas_fingerprint = "92429807C9853C0744A68B9AAE07828059A53CC1"
 sys.path.insert(0, '..')
 from zeroinstall.injector import trust
 from zeroinstall import SafeException
-from zeroinstall.support import basedir
 
 class TestTrust(BaseTest):
 	def testInit(self):
