@@ -1,10 +1,9 @@
-# Copyright (C) 2007, Thomas Leonard
+# Copyright (C) 2009, Thomas Leonard
 # See http://0install.net/0compile.html
 
 import sys, os
 import gtk, pango
 import dialog
-import logging
 
 import zeroinstall
 from zeroinstall import support
@@ -41,9 +40,19 @@ def report_bug(policy, iface):
 				text += '  From feed: %s\n' % impl.feed.url
 			text += '         ID: %s\n' % impl.id
 		else:
-			text += '    No implementation selected\n'
+			impls = policy.solver.details.get(chosen_iface, None)
+			if impls:
+				best, reason = impls[0]
+				note = 'best was %s, but: %s' % (best, reason)
+			else:
+				note = 'not considered; %d available' % len(chosen_iface.implementations)
 
-	text += '\nSystem:\n  %s\n\nIssue:\n  %s\n' % ('\n  '.join(os.uname()), issue)
+			text += '    No implementation selected (%s)\n' % note
+
+	if hasattr(os, 'uname'):
+		text += '\nSystem:\n  %s\n\nIssue:\n  %s\n' % ('\n  '.join(os.uname()), issue)
+	else:
+		text += '\nSystem without uname()\n'
 
 	reporter = BugReporter(policy, iface, text)
 	reporter.show()
@@ -160,9 +169,6 @@ class BugReporter(dialog.Dialog):
 		self.show_all()
 
 	def collect_output(self, buffer):
-		import logging
-		from zeroinstall.injector import run
-
 		iter = buffer.get_end_iter()
 		buffer.place_cursor(iter)
 
