@@ -1,9 +1,9 @@
-# Copyright (C) 2008, Thomas Leonard
+# Copyright (C) 2009, Thomas Leonard
 # See the README file for details, or visit http://0install.net.
 
 import gtk, gobject, pango
 
-from zeroinstall.support import basedir, tasks, pretty_size
+from zeroinstall.support import tasks, pretty_size
 from zeroinstall.injector.iface_cache import iface_cache
 from zeroinstall.injector import model
 import properties
@@ -249,6 +249,31 @@ class InterfaceBrowser:
 		assert isinstance(root, model.Interface)
 		self.root = root
 	
+	def _get_icon_from_cache(self, iface):
+		path = iface_cache.get_icon_path(iface)
+		if path:
+			try:
+				loader = gtk.gdk.PixbufLoader('png')
+				try:
+					loader.write(file(path).read())
+				finally:
+					loader.close()
+				icon = loader.get_pixbuf()
+				assert icon, "Failed to load cached PNG icon data"
+			except Exception, ex:
+				warn("Failed to load cached PNG icon: %s", ex)
+				return None
+			w = icon.get_width()
+			h = icon.get_height()
+			scale = max(w, h, 1) / ICON_SIZE
+			icon = icon.scale_simple(int(w / scale),
+						 int(h / scale),
+						 gtk.gdk.INTERP_BILINEAR)
+			self.cached_icon[iface.uri] = icon
+			return icon
+		else:
+			return None
+
 	def get_icon(self, iface):
 		"""Get an icon for this interface. If the icon is in the cache, use that.
 		If not, start a download. If we already started a download (successful or
@@ -256,42 +281,34 @@ class InterfaceBrowser:
 		try:
 			return self.cached_icon[iface.uri]
 		except KeyError:
-			path = iface_cache.get_icon_path(iface)
-			if path:
-				try:
-					loader = gtk.gdk.PixbufLoader('png')
-					try:
-						loader.write(file(path).read())
-					finally:
-						loader.close()
-					icon = loader.get_pixbuf()
-					assert icon, "Failed to load cached PNG icon data"
-				except Exception, ex:
-					warn("Failed to load cached PNG icon: %s", ex)
-					return None
-				w = icon.get_width()
-				h = icon.get_height()
-				scale = max(w, h, 1) / ICON_SIZE
-				icon = icon.scale_simple(int(w / scale),
-							 int(h / scale),
-							 gtk.gdk.INTERP_BILINEAR)
-				self.cached_icon[iface.uri] = icon
+			icon = self._get_icon_from_cache(iface)
+			if icon:
 				return icon
 			else:
 				# Try to download the icon
 				fetcher = self.policy.download_icon(iface)
 				if fetcher:
+					self.cached_icon[iface.uri] = None	# Only try once
 					@tasks.async
 					def update_display():
 						yield fetcher
 						try:
 							tasks.check(fetcher)
+							# Try to insert new icon into the cache
+							# If it fails, we'll be left with None in the cached_icon so
+							# we don't try again.
+							self._get_icon_from_cache(iface)
 							self.build_tree()
 						except Exception, ex:
 							import traceback
 							traceback.print_exc()
 							self.policy.handler.report_error(ex)
 					update_display()
+				# Note: if no icon is available for downloading,
+				# more attempts are made later.
+				# It can happen that no icon is yet available because
+				# the interface was not downloaded yet, in which case
+				# it's desireable to try again once the interface is available
 
 		return None
 
@@ -319,7 +336,7 @@ class InterfaceBrowser:
 				old_impl = self.original_implementation.get(iface, None)
 				version_str = impl.get_version()
 				if old_impl is not None and old_impl is not impl:
-					version_str += " (was " + old_impl.get_version() + ")"
+					version_str += _(' (was %s)') % old_impl.get_version()
 				self.model[iter][InterfaceBrowser.VERSION] = version_str
 
 				self.model[iter][InterfaceBrowser.DOWNLOAD_SIZE] = utils.get_fetch_info(self.policy, impl)
@@ -335,10 +352,10 @@ class InterfaceBrowser:
 						child_iter = self.model.append(parent)
 						self.model[child_iter][InterfaceBrowser.INTERFACE_NAME] = '?'
 						self.model[child_iter][InterfaceBrowser.SUMMARY] = \
-							'Unknown dependency type : %s' % child
+							_('Unknown dependency type : %s') % child
 						self.model[child_iter][InterfaceBrowser.ICON] = self.default_icon
 			else:
-				self.model[iter][InterfaceBrowser.VERSION] = '(choose)'
+				self.model[iter][InterfaceBrowser.VERSION] = _('(choose)')
 		add_node(None, self.root)
 		self.tree_view.expand_all()
 	
@@ -411,10 +428,10 @@ class InterfaceBrowser:
 				if expected:
 					fraction = "%s [%.2f%%]" % (pretty_size(expected), 100 * so_far / float(expected))
 				else:
-					fraction = "unknown"
+					fraction = _("unknown")
 				if len(downloads) > 1:
-					fraction += " in %d downloads" % len(downloads)
-				row[InterfaceBrowser.SUMMARY] = "(downloading %s/%s)" % (pretty_size(so_far), fraction)
+					fraction += _(" in %d downloads") % len(downloads)
+				row[InterfaceBrowser.SUMMARY] = _("(downloading %s/%s)") % (pretty_size(so_far), fraction)
 			else:
 				row[InterfaceBrowser.DOWNLOAD_SIZE] = utils.get_fetch_info(self.policy, impl)
 				row[InterfaceBrowser.SUMMARY] = iface.summary
