@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Thomas Leonard
+# Copyright (C) 2009, Thomas Leonard
 # See the README file for details, or visit http://0install.net.
 
 import gtk, gobject, os
@@ -71,14 +71,14 @@ class ImplementationList:
 		text = gtk.CellRendererText()
 		text_strike = gtk.CellRendererText()
 
-		stability = gtk.TreeViewColumn('Stability', text, text = STABILITY)
+		stability = gtk.TreeViewColumn(_('Stability'), text, text = STABILITY)
 
-		for column in (gtk.TreeViewColumn('Version', text_strike, text = VERSION, strikethrough = UNUSABLE),
-			       gtk.TreeViewColumn('Released', text, text = RELEASED),
+		for column in (gtk.TreeViewColumn(_('Version'), text_strike, text = VERSION, strikethrough = UNUSABLE),
+			       gtk.TreeViewColumn(_('Released'), text, text = RELEASED),
 			       stability,
-			       gtk.TreeViewColumn('Fetch', text, text = FETCH),
-			       gtk.TreeViewColumn('Arch', text_strike, text = ARCH, strikethrough = UNUSABLE),
-			       gtk.TreeViewColumn('Notes', text, text = NOTES)):
+			       gtk.TreeViewColumn(_('Fetch'), text, text = FETCH),
+			       gtk.TreeViewColumn(_('Arch'), text_strike, text = ARCH, strikethrough = UNUSABLE),
+			       gtk.TreeViewColumn(_('Notes'), text, text = NOTES)):
 			self.tree_view.append_column(column)
 
 		tips = ImplTips(policy, interface)
@@ -117,7 +117,7 @@ class ImplementationList:
 						impl.user_stability = new
 					else:
 						impl.user_stability = None
-					writer.save_interface(interface)
+					writer.save_feed(impl.feed)
 					self.policy.recalculate()
 				popup_menu(bev, ['Unset (%s)' % upstream, None] + choices,
 					set)
