@@ -1,15 +1,17 @@
-# Copyright (C) 2008, Thomas Leonard
+# Copyright (C) 2009, Thomas Leonard
 # See the README file for details, or visit http://0install.net.
 
 import gtk
-from logging import warn
-import os, sys
+import sys
+from logging import info
+
 from zeroinstall import SafeException
 from zeroinstall.support import tasks, pretty_size
-from zeroinstall.injector import download
+from zeroinstall.injector import download, iface_cache
 from iface_browser import InterfaceBrowser
-import help_box
 import dialog
+from zeroinstall.gtkui import gtkutils
+from zeroinstall.gtkui import help_box
 
 tips = gtk.Tooltips()
 
@@ -18,11 +20,13 @@ SHOW_PREFERENCES = 0
 class MainWindow:
 	progress = None
 	progress_area = None
-	busy_pointer = None
 	browser = None
 	window = None
 	cancel_download_and_run = None
 	policy = None
+	comment = None
+	systray_icon = None
+	systray_icon_blocker = None
 
 	def __init__(self, policy, widgets, download_only):
 		self.policy = policy
@@ -34,13 +38,10 @@ class MainWindow:
 
 		self.progress = widgets.get_widget('progress')
 		self.progress_area = widgets.get_widget('progress_area')
+		self.comment = widgets.get_widget('comment')
 
 		widgets.get_widget('stop').connect('clicked', lambda b: policy.handler.abort_all_downloads())
 
-		cache = widgets.get_widget('show_cache')
-		cache.connect('clicked',
-			lambda b: os.spawnlp(os.P_WAIT, sys.argv[0], sys.argv[0], '-c'))
-
 		self.refresh_button = widgets.get_widget('refresh')
 
 		# Tree view
@@ -51,12 +52,13 @@ class MainWindow:
 
 		# Glade won't let me add this to the template!
 		if download_only:
-			run_button = dialog.MixedButton("_Download", gtk.STOCK_EXECUTE, button = gtk.ToggleButton())
+			run_button = dialog.MixedButton(_("_Download"), gtk.STOCK_EXECUTE, button = gtk.ToggleButton())
 		else:
-			run_button = dialog.MixedButton("_Run", gtk.STOCK_EXECUTE, button = gtk.ToggleButton())
+			run_button = dialog.MixedButton(_("_Run"), gtk.STOCK_EXECUTE, button = gtk.ToggleButton())
 		self.window.add_action_widget(run_button, gtk.RESPONSE_OK)
 		run_button.show_all()
 		run_button.set_flags(gtk.CAN_DEFAULT)
+		self.run_button = run_button
 
 		self.window.set_default_response(gtk.RESPONSE_OK)
 		self.window.default_widget.grab_focus()
@@ -77,6 +79,7 @@ class MainWindow:
 				import preferences
 				preferences.show_preferences(policy)
 		self.window.connect('response', response)
+		self.window.realize()	# Make busy pointer work, even with --systray
 
 	def destroy(self):
 		self.window.destroy()
@@ -102,7 +105,7 @@ class MainWindow:
 					return
 
 			if self.policy.get_uncached_implementations():
-				dialog.alert(self.window, 'Not all downloads succeeded; cannot run program.')
+				dialog.alert(self.window, _('Not all downloads succeeded; cannot run program.'))
 			else:
 				from zeroinstall.injector import selections
 				sels = selections.Selections(self.policy)
@@ -111,16 +114,11 @@ class MainWindow:
 				sys.stdout.write(('Length:%8x\n' % len(reply)) + reply)
 				self.window.destroy()
 				sys.exit(0)			# Success
-		except SafeException, ex:
-			run_button.set_active(False)
-			self.policy.handler.report_error(ex)
 		except SystemExit:
 			raise
 		except Exception, ex:
 			run_button.set_active(False)
-			import traceback
-			traceback.print_exc()
-			self.policy.handler.report_error(ex)
+			self.report_exception(ex)
 
 	def update_download_status(self):
 		"""Called at regular intervals while there are downloads in progress,
@@ -136,9 +134,7 @@ class MainWindow:
 
 		if not self.progress_area.get_property('visible'):
 			self.progress_area.show()
-			if self.busy_pointer is None:
-				self.busy_pointer = dialog.get_busy_pointer(self.window.window)
-			self.window.window.set_cursor(self.busy_pointer)
+			self.window.window.set_cursor(gtkutils.get_busy_pointer())
 
 		any_known = False
 		done = total = self.policy.handler.total_bytes_downloaded	# Completed downloads
@@ -155,15 +151,52 @@ class MainWindow:
 
 		progress_text = '%s / %s' % (pretty_size(done), pretty_size(total))
 		if n_downloads == 1:
-			self.progress.set_text('Downloading one file (%s)' % progress_text)
+			self.progress.set_text(_('Downloading one file (%s)') % progress_text)
 		else:
-			self.progress.set_text('Downloading %d files (%s)' % (n_downloads, progress_text))
+			self.progress.set_text(_('Downloading %d files (%s)') % (n_downloads, progress_text))
 
 		if total == 0 or (n_downloads < 2 and not any_known):
 			self.progress.pulse()
 		else:
 			self.progress.set_fraction(float(done) / total)
 
+	def set_message(self, message):
+		import pango
+		self.comment.set_text(message)
+		attrs = pango.AttrList()
+		attrs.insert(pango.AttrWeight(pango.WEIGHT_BOLD, end_index = len(message)))
+		self.comment.set_attributes(attrs)
+		self.comment.show()
+
+	def use_systray_icon(self):
+		try:
+			self.systray_icon = gtk.status_icon_new_from_icon_name("zeroinstall-zero2desktop")
+		except Exception, ex:
+			info("No system tray support: %s", ex)
+		else:
+			root_iface = iface_cache.iface_cache.get_interface(self.policy.root)
+			self.systray_icon.set_tooltip('Checking for updates for %s' % root_iface.get_name())
+			self.systray_icon.connect('activate', self.remove_systray_icon)
+			self.systray_icon_blocker = tasks.Blocker('Tray icon clicked')
+
+	def remove_systray_icon(self, i = None):
+		assert self.systray_icon, i
+		self.show()
+		self.systray_icon.set_visible(False)
+		self.systray_icon = None
+		self.systray_icon_blocker.trigger()
+		self.systray_icon_blocker = None
+
+	def report_exception(self, ex):
+		if not isinstance(ex, SafeException):
+			import traceback
+			traceback.print_exc()
+		if self.systray_icon:
+			self.systray_icon.set_blinking(True)
+			self.systray_icon.set_tooltip(str(ex) + '\n(click for details)')
+		else:
+			dialog.alert(self.window, str(ex))
+
 gui_help = help_box.HelpBox("Injector Help",
 ('Overview', """
 A program is made up of many different components, typically written by different \
@@ -205,7 +238,7 @@ bug if necessary, or switch to using a different version of the library.
 
 ('The cache', """
 Each version of a program that is downloaded is stored in the Zero Install cache. This \
-means that it won't need to be downloaded again each time you run the program. Click on \
-the 'Show Cache' button to see what is currently in the cache, or to remove versions \
-you no longer need to save disk space."""),
+means that it won't need to be downloaded again each time you run the program. The \
+"0store manage" command can be used to view the cache.
+"""),
 )
