@@ -1,16 +1,16 @@
-# Copyright (C) 2008, Thomas Leonard
+# Copyright (C) 2009, Thomas Leonard
 # See the README file for details, or visit http://0install.net.
 
 import zeroinstall
 from zeroinstall.support import tasks
-from zeroinstall.injector.model import *
+from zeroinstall.injector.model import Interface, Feed, stable, testing, developer, stability_levels
 from zeroinstall.injector.iface_cache import iface_cache
 from zeroinstall.injector import writer, namespaces, gpg
+from zeroinstall.gtkui import help_box
 
-import gtk, sys, os
+import gtk
 from logging import warn
 
-import help_box
 from dialog import DialogResponse, Template
 from impl_list import ImplementationList
 import time
@@ -196,8 +196,8 @@ class Feeds:
 		self.tv = widgets.get_widget('feeds_list')
 		self.tv.set_model(self.model)
 		text = gtk.CellRendererText()
-		self.tv.append_column(gtk.TreeViewColumn('Source', text, text = Feeds.URI, sensitive = Feeds.USED))
-		self.tv.append_column(gtk.TreeViewColumn('Arch', text, text = Feeds.ARCH, sensitive = Feeds.USED))
+		self.tv.append_column(gtk.TreeViewColumn(_('Source'), text, text = Feeds.URI, sensitive = Feeds.USED))
+		self.tv.append_column(gtk.TreeViewColumn(_('Arch'), text, text = Feeds.ARCH, sensitive = Feeds.USED))
 
 		sel = self.tv.get_selection()
 		sel.set_mode(gtk.SELECTION_BROWSE)
@@ -325,7 +325,8 @@ class Properties:
 		ranked_items = self.policy.solver.details.get(self.interface, None)
 		if ranked_items is None:
 			# The Solver didn't get this far, but we should still display them!
-			ranked_items = self.interface.implementations.values()
+			ranked_items = [(impl, "(solve aborted before here)")
+					for impl in self.interface.implementations.values()]
 			ranked_items.sort()
 		self.use_list.set_items(ranked_items)
 
@@ -372,7 +373,7 @@ def add_remote_feed(policy, parent, interface):
 				try:
 					url = entry.get_text()
 					if not url:
-						raise SafeException(_('Enter a URL'))
+						raise zeroinstall.SafeException(_('Enter a URL'))
 					fetch = policy.fetcher.download_and_import_feed(url, iface_cache)
 					if fetch:
 						d.set_sensitive(False)
@@ -398,7 +399,7 @@ def add_remote_feed(policy, parent, interface):
 							writer.save_interface(interface)
 							d.destroy()
 							policy.recalculate()
-				except SafeException, ex:
+				except zeroinstall.SafeException, ex:
 					error(str(ex))
 			else:
 				d.destroy()
@@ -412,7 +413,6 @@ def add_local_feed(policy, interface):
 	sel = gtk.FileSelection(_('Select XML feed file'))
 	sel.set_has_separator(False)
 	def ok(b):
-		from xml.dom import minidom
 		from zeroinstall.injector import reader
 		feed = sel.get_filename()
 		try:
