@@ -1,15 +1,14 @@
-# Copyright (C) 2008, Thomas Leonard
+# Copyright (C) 2009, Thomas Leonard
 # -*- coding: utf-8 -*-
 # See the README file for details, or visit http://0install.net.
 
 import gtk
 from zeroinstall.injector.model import SafeException
 from zeroinstall.injector import gpg, trust
-from zeroinstall.injector.iface_cache import iface_cache
 from zeroinstall.support import tasks
+from zeroinstall.gtkui import help_box
 
-import gui
-import dialog, help_box
+import dialog
 
 def pretty_fp(fp):
 	s = fp[0:4]
@@ -294,7 +293,11 @@ hints = {
 
 	'635469E565B8D340C2C9EA4C32FBC18CE63EF486' :
 		'Eric Wasylishen is experimenting with packaging software with Zero Install. '
-		'This key was announced on the zero-install mailing list on 2007-01-16.',
+		'This key was announced on the zero-install mailing list on 2007-01-16 and then lost.',
+
+	'E5175248514E9D4E558B5925BC456918F32AC5D1' :
+		'Eric Wasylishen is experimenting with packaging software with Zero Install. '
+		'This key was announced on the zero-install mailing list on 2008-12-07',
 
 	'C82D382AAB381A54529019D6A0F9B035686C6996' :
 		"Justus Winter is generating Zero Install feeds from pkgsrc (which was originally "
@@ -315,5 +318,9 @@ hints = {
 	
 	'520DCCDBE5D38E2B22ADD82672E5E2ACF037FFC4' :
 		'Thierry Goubier creates PPC binaries for the ROX desktop. This key was '
-		'announced in a 2008-02-03 posting to the rox-users list.'
+		'announced in a 2008-02-03 posting to the rox-users list.',
+
+	'517085B7261D3B03A97515319C2C2CD1D41AF5BB' :
+		'Frank Richter is a developer of the Crystal Space 3D SDK. This key was '
+		'confirmed in a 2008-09-04 post to the zero-install-devel mailing list.',
 }
