@@ -10,7 +10,7 @@ from optparse import OptionParser
 import logging
 
 from zeroinstall import SafeException, NeedDownload
-from zeroinstall.injector import model, autopolicy, namespaces
+from zeroinstall.injector import model, autopolicy, namespaces, selections
 from zeroinstall.injector.iface_cache import iface_cache
 
 #def program_log(msg): os.access('MARK: 0launch: ' + msg, os.F_OK)
@@ -210,8 +210,8 @@ def _normal_mode(options, args):
 	prog_args = args[1:]
 
 	try:
+		from zeroinstall.injector import run
 		if options.gui:
-			from zeroinstall.injector import run
 			gui_args = []
 			if options.download_only:
 				# Just changes the button's label
@@ -241,18 +241,26 @@ def _normal_mode(options, args):
 			if options.os:
 				gui_args.insert(0, options.os)
 				gui_args.insert(0, '--os')
+			if options.with_store:
+				for x in options.with_store:
+					gui_args += ['--with-store', x]
 			sels = _fork_gui(iface_uri, gui_args, prog_args, options)
 			if not sels:
 				sys.exit(1)		# Aborted
-			if options.get_selections:
-				doc = sels.toDOM()
-				doc.writexml(sys.stdout)
-				sys.stdout.write('\n')
-			elif not options.download_only:
-				run.execute_selections(sels, prog_args, options.dry_run, options.main, options.wrapper)
 		else:
 			#program_log('download_and_execute ' + iface_uri)
-			policy.download_and_execute(prog_args, refresh = bool(options.refresh), main = options.main)
+			downloaded = policy.solve_and_download_impls(refresh = bool(options.refresh))
+			if downloaded:
+				policy.handler.wait_for_blocker(downloaded)
+			sels = selections.Selections(policy)
+
+		if options.get_selections:
+			doc = sels.toDOM()
+			doc.writexml(sys.stdout)
+			sys.stdout.write('\n')
+		elif not options.download_only:
+			run.execute_selections(sels, prog_args, options.dry_run, options.main, options.wrapper)
+
 	except NeedDownload, ex:
 		# This only happens for dry runs
 		print ex
@@ -280,7 +288,6 @@ def _download_missing_selections(options, sels):
 		handler.wait_for_blocker(blocker)
 
 def _get_selections(policy):
-	import selections
 	doc = selections.Selections(policy).toDOM()
 	doc.writexml(sys.stdout)
 	sys.stdout.write('\n')
@@ -327,6 +334,7 @@ def main(command_args):
 	parser.add_option("", "--systray", help="download in the background", action='store_true')
 	parser.add_option("-v", "--verbose", help="more verbose output", action='count')
 	parser.add_option("-V", "--version", help="display version information", action='store_true')
+	parser.add_option("", "--with-store", help="add an implementation cache", action='append', metavar='DIR')
 	parser.add_option("-w", "--wrapper", help="execute program using a debugger, etc", metavar='COMMAND')
 	parser.disable_interspersed_args()
 
@@ -341,6 +349,12 @@ def main(command_args):
 		import zeroinstall
 		logging.info("Running 0launch %s %s; Python %s", zeroinstall.version, repr(args), sys.version)
 
+	if options.with_store:
+		from zeroinstall import zerostore
+		for x in options.with_store:
+			iface_cache.stores.stores.append(zerostore.Store(os.path.abspath(x)))
+		logging.info("Stores search path is now %s", iface_cache.stores.stores)
+
 	try:
 		if options.list:
 			_list_interfaces(args)
@@ -354,7 +368,7 @@ def main(command_args):
 			print "under the terms of the GNU Lesser General Public License."
 			print "For more information about these matters, see the file named COPYING."
 		elif options.set_selections:
-			from zeroinstall.injector import selections, qdom, run
+			from zeroinstall.injector import qdom, run
 			sels = selections.Selections(qdom.parse(file(options.set_selections)))
 			_download_missing_selections(options, sels)
 			if not options.download_only:
