@@ -45,7 +45,7 @@ class Download(object):
 	@ivar hint: hint passed by and for caller
 	@type hint: object
 	@ivar child: the child process
-	@type child: L{subprocess.Popen}
+	@type child: subprocess.Popen
 	@ivar aborted_by_user: whether anyone has called L{abort}
 	@type aborted_by_user: bool
 	"""
@@ -201,8 +201,12 @@ if __name__ == '__main__':
 			else:
 				raise Exception('Unsupported URL protocol in: ' + url)
 
+			try:
+				sock = src.fp._sock
+			except AttributeError:
+				sock = src.fp.fp._sock	# Python 2.5 on FreeBSD
 			while True:
-				data = src.fp._sock.recv(256)
+				data = sock.recv(256)
 				if not data: break
 				os.write(1, data)
 
