@@ -4,7 +4,7 @@ Manages the feed cache.
 @var iface_cache: A singleton cache object. You should normally use this rather than
 creating new cache objects.
 """
-# Copyright (C) 2008, Thomas Leonard
+# Copyright (C) 2009, Thomas Leonard
 # See the README file for details, or visit http://0install.net.
 
 # Note:
@@ -33,9 +33,9 @@ from cStringIO import StringIO
 
 from zeroinstall.support import basedir
 from zeroinstall.injector import reader, model
-from zeroinstall.injector.namespaces import *
-from zeroinstall.injector.model import *
-from zeroinstall import zerostore
+from zeroinstall.injector.namespaces import config_site, config_prog
+from zeroinstall.injector.model import Interface, escape, unescape
+from zeroinstall import zerostore, SafeException
 
 def _pretty_time(t):
 	assert isinstance(t, (int, long)), t
@@ -156,7 +156,7 @@ class PendingFeed(object):
 			self.sigs = sigs
 		except:
 			self.signed_data.seek(0)
-			info("Failed to check GPG signature. Data received was:\n" + `self.signed_data.read()`)
+			info("Failed to check GPG signature. Data received was:\n" + repr(self.signed_data.read()))
 			raise
 
 class IfaceCache(object):
@@ -214,7 +214,7 @@ class IfaceCache(object):
 		@param modified_time: the timestamp of the oldest trusted signature
 		(used as an approximation to the interface's modification time)
 		@type modified_time: long
-		@raises SafeException: if modified_time is older than the currently cached time
+		@raises ReplayAttack: if modified_time is older than the currently cached time
 		"""
 		debug("Updating '%s' from network; modified at %s" %
 			(interface.name or interface.uri, _pretty_time(modified_time)))
@@ -245,7 +245,7 @@ class IfaceCache(object):
 		@param interface: updated once the new XML is written
 		@param new_xml: the data to write
 		@param modified_time: when new_xml was modified
-		@raises SafeException: if the new mtime is older than the current one
+		@raises ReplayAttack: if the new mtime is older than the current one
 		"""
 		assert modified_time
 
@@ -392,6 +392,7 @@ class IfaceCache(object):
 		timestamp_path = os.path.join(feeds_dir, model._pretty_escape(url))
 		fd = os.open(timestamp_path, os.O_WRONLY | os.O_CREAT, 0644)
 		os.close(fd)
+		os.utime(timestamp_path, None)	# In case file already exists
 
 	def get_last_check_attempt(self, url):
 		"""Return the time of the most recent update attempt for a feed.
