@@ -2,22 +2,18 @@
 Parses an XML interface into a Python representation.
 """
 
-# Copyright (C) 2006, Thomas Leonard
+# Copyright (C) 2009, Thomas Leonard
 # See the README file for details, or visit http://0install.net.
 
 import os
-import sys
-import shutil
-import time
-from logging import debug, warn, info
+from logging import debug, info, warn
 from os.path import dirname
 
 from zeroinstall.support import basedir
 from zeroinstall.injector import qdom, distro
-from zeroinstall.injector.namespaces import *
-from zeroinstall.injector.model import *
+from zeroinstall.injector.namespaces import config_site, config_prog, XMLNS_IFACE, injector_gui_uri
+from zeroinstall.injector.model import Interface, InvalidInterface, ZeroInstallFeed, escape, Feed, stability_levels
 from zeroinstall.injector import model
-from zeroinstall import version, SafeException
 
 def update_from_cache(interface):
 	"""Read a cached interface and any native feeds or user overrides.
@@ -68,7 +64,11 @@ def update_user_overrides(interface, main_feed = None):
 	if not user:
 		return
 
-	root = qdom.parse(file(user))
+	try:
+		root = qdom.parse(file(user))
+	except Exception, ex:
+		warn("Error reading '%s': %s", user, ex)
+		raise
 
 	# This is a bit wrong; this information is about the feed,
 	# not the interface.
