@@ -2,13 +2,13 @@
 Executes a set of implementations as a program.
 """
 
-# Copyright (C) 2006, Thomas Leonard
+# Copyright (C) 2009, Thomas Leonard
 # See the README file for details, or visit http://0install.net.
 
 import os, sys
 from logging import debug, info
 
-from zeroinstall.injector.model import Interface, SafeException, EnvironmentBinding, DistributionImplementation, ZeroInstallImplementation
+from zeroinstall.injector.model import SafeException, EnvironmentBinding, ZeroInstallImplementation
 from zeroinstall.injector.iface_cache import iface_cache
 
 def do_env_binding(binding, path):
@@ -38,8 +38,7 @@ def execute(policy, prog_args, dry_run = False, main = None, wrapper = None):
 	"""
 	iface = iface_cache.get_interface(policy.root)
 		
-	for needed_iface in policy.implementation:
-		impl = policy.implementation[needed_iface]
+	for impl in policy.implementation.values():
 		assert impl
 		_do_bindings(impl, impl.bindings)
 		for dep in impl.requires:
