@@ -1,9 +1,9 @@
 """Unpacking archives of various formats."""
 
-# Copyright (C) 2006, Thomas Leonard
+# Copyright (C) 2009, Thomas Leonard
 # See the README file for details, or visit http://0install.net.
 
-import os
+import os, subprocess
 import shutil
 import traceback
 from tempfile import mkdtemp, mkstemp
@@ -101,9 +101,7 @@ def check_type_ok(mime_type):
 			raise SafeException("This package looks like a Microsoft Cabinet archive, but you don't have the 'cabextract' command "
 					"I need to extract it. Install the package containing it first.")
 	elif mime_type == 'application/x-lzma-compressed-tar':
-		if not find_in_path('unlzma'):
-			raise SafeException("This package looks like an LZMA archive, but you don't have the 'unlzma' command "
-					"I need to extract it. Install the package containing it (it's probably called 'lzma') first.")
+		pass	# We can get it through Zero Install
 	elif mime_type in ('application/x-compressed-tar', 'application/x-tar'):
 		pass
 	else:
@@ -313,7 +311,10 @@ def extract_tar(stream, destdir, extract, decompress, start_offset = 0):
 			elif decompress == 'gzip':
 				ext_cmd.append('-z')
 			elif decompress == 'lzma':
-				ext_cmd.append('--use-compress-program=unlzma')
+				unlzma = find_in_path('unlzma')
+				if not unlzma:
+					unlzma = os.path.abspath(os.path.join(os.path.dirname(__file__), '_unlzma'))
+				ext_cmd.append('--use-compress-program=' + unlzma)
 
 		if recent_gnu_tar():
 			ext_cmd.extend(('-x', '--no-same-owner', '--no-same-permissions'))
@@ -396,22 +397,16 @@ def extract_tar(stream, destdir, extract, decompress, start_offset = 0):
 def _extract(stream, destdir, command, start_offset = 0):
 	"""Run execvp('command') inside destdir in a child process, with
 	stream seeked to 'start_offset' as stdin."""
-	child = os.fork()
-	if child == 0:
-		try:
-			try:
-				# Some zip archives are missing timezone information; force consistent results
-				os.environ['TZ'] = 'GMT'
 
-				os.chdir(destdir)
-				stream.seek(start_offset)
-				os.dup2(stream.fileno(), 0)
-				_exec_maybe_sandboxed(destdir, *command)
-			except:
-				traceback.print_exc()
-		finally:
-			os._exit(1)
-	id, status = os.waitpid(child, 0)
-	assert id == child
+	# Some zip archives are missing timezone information; force consistent results
+	child_env = os.environ.copy()
+	child_env['TZ'] = 'GMT'
+
+	stream.seek(start_offset)
+
+	# TODO: use pola-run if available, once it supports fchmod
+	child = subprocess.Popen(command, cwd = destdir, stdin = stream, env = child_env)
+
+	status = child.wait()
 	if status != 0:
 		raise SafeException('Failed to extract archive; exit code %d' % status)
